@@ -30,7 +30,7 @@
 // POSSIBILITY OF SUCH DAMAGE.
 // ************************************************************************* 
 //
-// app/dmenu.js
+// app/dmenu-init.js
 //
 // Round one of dmenu initialization - called from app/target-init.js
 //
@@ -50,7 +50,7 @@ define ([
             'menuText': 'Demo menu',
             'title': 'Demo menu',
             'aclProfile': 'passerby',
-            'entries': ['demoActionFromMenu', 'demoSubmenu' ],
+            'entries': ['demoActionFromMenu', 'demoNotice', 'demoSubmenu' ],
             'back': 'logout'
         });
 
@@ -60,7 +60,7 @@ define ([
             'menuText': 'Demo submenu',
             'title': 'Demo submenu',
             'aclProfile': 'passerby',
-            'entries': ['demoActionFromSubmenu', 'demoForm' ],
+            'entries': ['demoActionFromSubmenu', 'demoForm', 'demoBrowser' ],
             'back': 'demoMenu'
         });
 
